<?php

class DotPressAdmin
{

    private $plugin_name;
    private $version;
    /**
     * @var DotPressLoader
     */
    private $loader;
    private $token_name = DOT_PRESS_TOKEN_NAME;

    /**
     * Initialize the class and set its properties.
     *
     * @param string $plugin_name The name of this plugin.
     * @param string $version The version of this plugin.
     * @param DotPressLoader $loader
     * @since    1.0.0
     */
    public function __construct($plugin_name, $version, $loader)
    {

        $this->plugin_name = $plugin_name;
        $this->version = $version;
        $this->loader = $loader;
        $page = DotPressRequestUtils::safelyGetStringVar('page');

//        $this->loader->add_action('admin_enqueue_scripts', $this, 'enqueue_styles');
        if ($page === 'dot-press') {
            $this->loader->add_action('admin_enqueue_scripts', $this, 'enqueue_scripts');
        }
        $this->loader->add_action('admin_menu', $this, 'register_option_page');
        $this->loader->add_filter("plugin_action_links_" . DOT_PRESS_BASENAME, $this, 'add_settings_link');
        $this->loader->add_action('wp_ajax_dot_press_save_token', $this, 'save_token');
        $this->loader->add_action('wp_ajax_dot_press_get_token', $this, 'get_token');
        $this->loader->add_action('wp_ajax_dot_press_delete_token', $this, 'delete_token');

    }

    public function add_settings_link($links)
    {
        $settings_link = '<a href="options-general.php?page=dot-press">Settings</a>';
        array_unshift($links, $settings_link);
        return $links;
    }

    public function enqueue_styles()
    {
//        wp_enqueue_style($this->plugin_name, plugin_dir_url(__FILE__) . 'css/dot-press-admin.css', array(), $this->version, 'all');
    }

    public function enqueue_scripts()
    {
        wp_enqueue_script($this->plugin_name, DOT_PRESS_ROOT_URL . 'js/dist/dot-press-admin.js', array(), filemtime(DOT_PRESS_ROOT . 'js/dist/dot-press-admin.js'), true);
        wp_localize_script($this->plugin_name, 'dotPress', [
            'pluginUrlPath' => DOT_PRESS_ROOT_URL,
            'jsUrlPath' => DOT_PRESS_ROOT_URL . 'js/dist',
            'admin' => admin_url('/')
        ]);
    }

    public function register_option_page()
    {
        add_options_page('DOT', 'DOT', 'manage_options', $this->plugin_name, [$this, 'register_option_page_routes']);
    }

    public function register_option_page_routes()
    {
        include_once DOT_PRESS_ROOT . 'views/admin-page.php';
    }

    public function save_token()
    {
        if (!get_option($this->token_name)) {
            add_option($this->token_name, DotPressRequestUtils::safelyGetStringVar('token'));
        } else {
            update_option($this->token_name, DotPressRequestUtils::safelyGetStringVar('token'));
        }

        wp_send_json(['status' => 'SUCCESS', 'payload' => true]);
    }

    public function get_token()
    {
        wp_send_json(['status' => 'SUCCESS', 'payload' => get_option($this->token_name)]);
    }

    public function delete_token() {
        wp_send_json(['status' => 'SUCCESS', 'payload' => delete_option($this->token_name)]);
    }

}