<?php

/**
 * The admin-specific functionality of the plugin.
 *
 * @link       http://example.com
 * @since      1.0.0
 *
 * @package    Plugin_Name
 * @subpackage Plugin_Name/admin
 */

/**
 * The admin-specific functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    Plugin_Name
 * @subpackage Plugin_Name/admin
 * @author     Your Name <email@example.com>
 */
class DotPressPublic
{

    /**
     * The ID of this plugin.
     *
     * @since    1.0.0
     * @access   private
     * @var      string $plugin_name The ID of this plugin.
     */
    private $plugin_name;

    /**
     * The version of this plugin.
     *
     * @since    1.0.0
     * @access   private
     * @var      string $version The current version of this plugin.
     */
    private $version;

    private $loader;

    /**
     * @var DotPressBlockRenderer
     */
    private $renderer;

    private $content_render_counter = 0;

    /**
     * Initialize the class and set its properties.
     *
     * @param string $plugin_name The name of this plugin.
     * @param string $version The version of this plugin.
     * @param DotPressLoader $loader
     * @since    1.0.0
     */
    public function __construct($plugin_name, $version, $loader)
    {

        $this->plugin_name = $plugin_name;
        $this->version = $version;
        $this->loader = $loader;

        $this->loader->add_action('wp_enqueue_scripts', $this, 'enqueue_scripts');
        $this->loader->add_action('wp', $this, 'load_renderer', 1);
        $this->loader->add_filter('ampforwp_post_content_filter', $this, 'render_ampforwp_content');
        $this->loader->add_filter('the_content', $this, 'render_placement_content');
        $this->loader->add_action('the_post', $this, 'modify_post_content', 9999);
    }

    /**
     * Register the JavaScript for the admin area.
     *
     * @since    1.0.0
     */
    public function enqueue_scripts()
    {

        /**
         * This function is provided for demonstration purposes only.
         *
         * An instance of this class should be passed to the run() function
         * defined in DotPressLoader as all of the hooks are defined
         * in that particular class.
         *
         * The DotPressLoader will then create the relationship
         * between the defined hooks and the functions defined in this
         * class.
         */

        wp_enqueue_script($this->plugin_name, DOT_PRESS_ROOT_URL . 'js/dist/dot-press-public.js', array('jquery'), filemtime(DOT_PRESS_ROOT . 'js/dist/dot-press-public.js'), false);

    }

    public function load_renderer()
    {
        if (DotPressWpUtils::is_front_end()) {
            global $post;
            $this->renderer = new DotPressBlockRenderer($post);

        }
    }

    public function render_ampforwp_content($content)
    {
        return $this->render_placement_content($this->render_block_content($content));
    }

    public function modify_post_content($post)
    {
        if (preg_match("/dot-press-blocks-added/", $post->post_content) > 0) {
            return $post;
        }

        $isAmpForWp = function_exists('ampforwp_is_amp_endpoint') && ampforwp_is_amp_endpoint();
        if (!DotPressWpUtils::is_front_end() || is_null($this->renderer) || $isAmpForWp) {
            return $post;
        }

        $post->post_content = $this->render_block_content($post->post_content) . "<!-- dot-press-blocks-added -->";
        return $post;
    }

    public function render_block_content($content)
    {

        $blocks = parse_blocks($content);
        $names = array_map(function ($b) {
            return $b['blockName'];
        }, $blocks);

        if (!in_array('core/paragraph', $names) && !in_array('core/image', $names)) {
            return $content;
        }

        $newBlocks = array_merge(...array_map(function ($block) {
            $parsed = parse_blocks($this->render_block(render_block($block), $block));
            return array_map(function ($parsedBlock) use ($block) {
                if ($block['innerHTML'] === $parsedBlock['innerHTML']) {
                    return $block;
                }

                return $parsedBlock;
            }, $parsed);
        }, $blocks));
        if (count($newBlocks) > count($blocks)) {
            return implode(array_map(function ($block) {
                return $block['innerHTML'];
            }, $newBlocks), '');
        }

        return $content;
    }

    public function render_block($block_content, $block)
    {
        if (!DotPressWpUtils::is_front_end() || is_null($this->renderer)) {
            return $block_content;
        }

        $block_type = $block['blockName'];
        return $this->renderer->render($block_type, $block_content, $block);
    }

    public function render_placement_content($content) {
        if (preg_match("/dot-press-content-added/", $content) > 0 || !is_singular('post')) {
            return $content;
        }
        return $this->renderer->renderContentPlacements($content) . "<!-- dot-press-content-added -->";
    }
}